<?php

namespace Drupal\transform_api\Plugin\Transform\Field;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\file\Entity\File;
use Drupal\transform_api\FieldTransformBase;

/**
 * Transform field plugin for file field types as Urls.
 *
 * @FieldTransform(
 *  id = "file_url",
 *  label = @Translation("File URL"),
 *  field_types = {
 *    "file"
 *  }
 * )
 */
class FileURLTransform extends FieldTransformBase {

  /**
   * {@inheritdoc}
   */
  public function transformElements(FieldItemListInterface $items, $langcode) {
    $values = [];
    /** @var \Drupal\Core\Field\FieldItemInterface $item */
    foreach ($items as $item) {
      if (!empty($item->getValue()['target_id'])) {
        // File ID.
        $fid = $item->getValue()['target_id'];
        // Load file.
        $file = File::load($fid);
        $file_uri = $file->getFileUri();

        $values[] = \Drupal::service('file_url_generator')->generateString($file_uri);
      }
      else {
        $values[] = NULL;
      }
    }
    return $values;
  }

}
